@@ -100,6 +100,10 @@ tiddler.text to HTML when tiddler.type is None.
 wikitext.type_render_map -- A dictionary mapping tiddler.type MIME-
 TYPES to modules with a render() function for turning that content-type
 into HTML.
+
+special_bag_detectors -- A list of functions that take an environ and bag
+name and return a tuple of two functions: the first returns the tiddlers
+in that bag, the second returns one tiddler from that bag.
 """
 
 try:
@@ -176,6 +180,7 @@ DEFAULT_CONFIG = {
         'wikitext.default_renderer': 'raw',
         'wikitext.type_render_map': {},
         'root_dir': '',
+        'special_bag_detectors': [],
         }
 
 
